==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UDPRouteListFluent<A extends UDPRouteListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,UDPRoute item);
  public A setToItems(Integer index,UDPRoute item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRoute... items);
  public A addAllToItems(Collection<UDPRoute> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRoute... items);
  public A removeAllFromItems(Collection<UDPRoute> items);
  public A removeMatchingFromItems(Predicate<UDPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<UDPRoute> getItems();
  public List<UDPRoute> buildItems();
  public UDPRoute buildItem(Integer index);
  public UDPRoute buildFirstItem();
  public UDPRoute buildLastItem();
  public UDPRoute buildMatchingItem(Predicate<UDPRouteBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<UDPRouteBuilder> predicate);
  public A withItems(List<UDPRoute> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRoute... items);
  public Boolean hasItems();
  public UDPRouteListFluent.ItemsNested<A> addNewItem();
  public UDPRouteListFluent.ItemsNested<A> addNewItemLike(UDPRoute item);
  public UDPRouteListFluent.ItemsNested<A> setNewItemLike(Integer index,UDPRoute item);
  public UDPRouteListFluent.ItemsNested<A> editItem(Integer index);
  public UDPRouteListFluent.ItemsNested<A> editFirstItem();
  public UDPRouteListFluent.ItemsNested<A> editLastItem();
  public UDPRouteListFluent.ItemsNested<A> editMatchingItem(Predicate<UDPRouteBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,UDPRouteFluent<UDPRouteListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UDPRouteListFluent<A extends UDPRouteListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,UDPRoute item);
  public A setToItems(int index,UDPRoute item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRoute... items);
  public A addAllToItems(Collection<UDPRoute> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRoute... items);
  public A removeAllFromItems(Collection<UDPRoute> items);
  public A removeMatchingFromItems(Predicate<UDPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<UDPRoute> getItems();
  public List<UDPRoute> buildItems();
  public UDPRoute buildItem(int index);
  public UDPRoute buildFirstItem();
  public UDPRoute buildLastItem();
  public UDPRoute buildMatchingItem(Predicate<UDPRouteBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<UDPRouteBuilder> predicate);
  public A withItems(List<UDPRoute> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.UDPRoute... items);
  public Boolean hasItems();
  public UDPRouteListFluent.ItemsNested<A> addNewItem();
  public UDPRouteListFluent.ItemsNested<A> addNewItemLike(UDPRoute item);
  public UDPRouteListFluent.ItemsNested<A> setNewItemLike(int index,UDPRoute item);
  public UDPRouteListFluent.ItemsNested<A> editItem(int index);
  public UDPRouteListFluent.ItemsNested<A> editFirstItem();
  public UDPRouteListFluent.ItemsNested<A> editLastItem();
  public UDPRouteListFluent.ItemsNested<A> editMatchingItem(Predicate<UDPRouteBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,UDPRouteFluent<UDPRouteListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
